.. _reference:

API Reference
=============
Welcome to the API documentation for the stravalib package.
Below the main modules are listed.

.. warning::
   Note that only public facing methods are documented here.

.. toctree::
   :maxdepth: 1

   Client <reference/client>
   Model <reference/model>
   Strava Model <reference/strava_model>
   Unit helper <reference/unithelper>
   Protocol <reference/protocol>
   Limiter (Util Submodule) <reference/utilities>
   Field Conversions <reference/field-conversions>
   Exceptions <reference/exceptions>
